pub fn serve_all_route_sets_with_table_id<I: FidlRouteAdminIpExt>(
server_end: ServerEnd<I::RouteTableMarker>,
table_id: Option<TableId>,
) -> impl Stream<Item = <<<I as FidlRouteAdminIpExt>::RouteSetMarker as ProtocolMarker>::RequestStream as Stream>::Item>Expand description
TODO(https://fxbug.dev/337298251): Change this to return a RouteSet index beside the RouteSet item to make it easier to determine which RouteSet pertains to the transmitted requests.
Provides a RouteTable implementation that consolidates all RouteSets into a single RouteSet stream. Returns a request stream that vends items as they arrive in any RouteSet.